@@ -5,7 +5,7 @@
 
 
 
-.pointBuffer <- function(xy, d, lonlat=TRUE, a=6378137, f=1/298.257223563, crs=NA, ... ) {
+.pointBuffer <- function(xy, d, lonlat=TRUE, a=6378137, f=1/298.257223563, crs="", ... ) {
 	
 	n <- list(...)$quadsegs
 	if (is.null(n)) {
@@ -71,18 +71,23 @@ function(x, width=1, dissolve=TRUE, ...) {
 			lonlat = FALSE
 		}
 		
-		pb <- .pointBuffer(xy=coordinates(x)[,1:2,drop=FALSE], d=width, lonlat=lonlat, crs=crs(x), ...)
+		pb <- .pointBuffer(xy=sp::coordinates(x)[,1:2,drop=FALSE], d=width, lonlat=lonlat, crs=crs(x), ...)
 
 		if (dissolve) {
 			pb <- aggregate(pb)
 		} else if (.hasSlot(x, 'data')) {
-			pb <- SpatialPolygonsDataFrame(pb, x@data, match.ID=FALSE)
+			pb <- sp::SpatialPolygonsDataFrame(pb, x@data, match.ID=FALSE)
 		}
 		return(pb)		
 	}
 	
-	stopifnot(requireNamespace("rgeos"))
-	rgeos::gBuffer(x, byid=!dissolve, width=width, ...)
+	valgeos <- .checkGEOS(); on.exit(rgeos::set_RGEOS_CheckValidity(valgeos))
+	
+	prj <- x@proj4string
+	x@proj4string <- sp::CRS(as.character(NA))
+	x <- rgeos::gBuffer(x, byid=!dissolve, width=width, ...)
+	x@proj4string <- prj
+	x
 }
 )
 
