@@ -8,6 +8,8 @@
 	compareCRS(...)
 }
 
+# see sp:identicalCRS(x, y)
+
 compareCRS <- function(x, y, unknown=FALSE, verbatim=FALSE, verbose=FALSE) {
 	
 	x <- tolower(projection(x))
@@ -47,7 +49,7 @@ compareCRS <- function(x, y, unknown=FALSE, verbatim=FALSE, verbose=FALSE) {
 			return(TRUE)
 		} else {
 			if (verbose) {
-				message('Unknown CRS')
+				message('Unknown crs')
 			}
 			return(FALSE) 
 		}
