@@ -82,11 +82,9 @@ function(x, y, ...) {
 
 setMethod('distance', signature(x='Spatial', y='Spatial'), 
 function(x, y, ...) {
-	if (!requireNamespace("rgeos")) {
-		stop('This function needs the rgeos package to be available')
-	} 
-	stopifnot(inherits(class(x), 'SpatialVector'))
-	stopifnot(inherits(class(y), 'SpatialVector'))	
+	valgeos <- .checkGEOS(); on.exit(rgeos::set_RGEOS_CheckValidity(valgeos))
+	stopifnot(inherits(x, 'SpatialVector'))
+	stopifnot(inherits(y, 'SpatialVector'))	
 	d <- rgeos::gDistance(x, y, byid=TRUE)
 	apply(d, 1, min)
 }
