@@ -6,7 +6,13 @@
 
 
 getData <- function(name='GADM', download=TRUE, path='', ...) {
+
 	path <- .getDataPath(path)
+
+	tout <- getOption("timeout")
+	on.exit(options(timeout = tout))
+	options(timeout = max(600, tout))
+	
 	if (name=='GADM') {
 		.GADM(..., download=download, path=path)
 	} else if (name=='SRTM') {
@@ -29,7 +35,7 @@ getData <- function(name='GADM', download=TRUE, path='', ...) {
 
 .download <- function(aurl, filename) {
 	fn <- paste(tempfile(), '.download', sep='')
-	res <- utils::download.file(url=aurl, destfile=fn, method="auto", quiet = FALSE, mode = "wb", cacheOK = TRUE)
+	res <- utils::download.file(url=aurl, destfile=fn, quiet = FALSE, mode = "wb", cacheOK = TRUE)
 	if (res == 0) {
 		w <- getOption('warn')
 		on.exit(options('warn' = w))
@@ -407,7 +413,7 @@ ccodes <- function() {
 	if (rowTile < 10) { rowTile <- paste('0', rowTile, sep='') }
 	if (colTile < 10) { colTile <- paste('0', colTile, sep='') }
 
-	baseurl <- "http://srtm.csi.cgiar.org/wp-content/uploads/files/srtm_5x5/TIFF/"
+	baseurl <- "https://srtm.csi.cgiar.org/wp-content/uploads/files/srtm_5x5/TIFF/"
 	
 	f <- paste0("srtm_", colTile, "_", rowTile, ".zip")
 
