@@ -233,7 +233,7 @@
 	}
 
 # check if bbox of raster and p overlap
-	spbb <- bbox(p)
+	spbb <- sp::bbox(p)
 	rsbb <- bbox(rstr)
 	if (spbb[1,1] >= rsbb[1,2] | spbb[1,2] <= rsbb[1,1] | spbb[2,1] >= rsbb[2,2] | spbb[2,2] <= rsbb[2,1]) {
 		# instead of a warning
@@ -357,9 +357,9 @@
 					if ((nrow(intersection) %% 2 == 1) || ( sum(x[-length(x)] == x[-1]) > 0 )) {
 					# uneven number or duplicates
 					# e.g. single node intersection going out of polygon ....
-						spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
-						spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
-						over <- over(spPnts, spPol)
+						spPnts <- sp::SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
+						spPol <- sp::SpatialPolygons(list(sp::Polygons(list(mypoly), 1)))
+						over <- sp::over(spPnts, spPol)
 						if ( subpol[i, 5] == 1 ) {
 							holes[!is.na(over)] <- holes[!is.na(over)] - 1
 						} else {
@@ -389,9 +389,9 @@
 							col1 <- leftColFromX(rstr, x1a)
 							col2 <- rightColFromX(rstr, x2a)
 							if (col1 > col2) { 
-								spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
-								spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
-								over <- over(spPnts, spPol)
+								spPnts <- sp::SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
+								spPol <- sp::SpatialPolygons(list(sp::Polygons(list(mypoly), 1)))
+								over <- sp::over(spPnts, spPol)
 								if ( subpol[i, 5] == 1 ) {
 									holes[!is.na(over)] <- holes[!is.na(over)] - 1
 								} else {
@@ -477,14 +477,11 @@
 #plot( .polygonsToRaster(p, rstr) )
 
 
-...polygoncover <- function(p, x, filename, ...) {
-	d <- disaggregate(raster(x), 10)
-	r <- .polygonsToRaster(p, d, filename=filename, field=1, fun='first', background=0, mask=FALSE, update=FALSE, getCover=FALSE, silent=TRUE, ...)
-	aggregate(r, 10, sum)
-	
-	
-	
-} 
+#...polygoncover <- function(p, x, filename, ...) {
+#	d <- disaggregate(raster(x), 10)
+#	r <- .polygonsToRaster(p, d, filename=filename, field=1, fun='first', background=0, mask=FALSE, update=FALSE, getCover=FALSE, silent=TRUE, ...)
+#	aggregate(r, 10, sum)
+#} 
 
 .Old_polygoncover <- function(rstr, filename, polinfo, lxmin, lxmax, pollist, ...) {
 # percentage cover per grid cell
@@ -544,9 +541,9 @@
 						#}
 						if ( sum(x[-length(x)] == x[-1]) > 0 ) {
 					# single node intersection going out of polygon ....
-							spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
-							spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
-							over <- over(spPnts, spPol)
+							spPnts <- sp::SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
+							spPol <- sp::SpatialPolygons(list(sp::Polygons(list(mypoly), 1)))
+							over <- sp::over(spPnts, spPol)
 							if ( subpol[i, 5] == 1 ) {
 								holes[!is.na(over)] <- holes[!is.na(over)] - 1
 							} else {
@@ -621,7 +618,7 @@
 	filename <- trim(filename)
 	raster <- raster(raster)
 	
-	spbb <- bbox(p)
+	spbb <- sp::bbox(p)
 	rsbb <- bbox(raster)
 	if (spbb[1,1] > rsbb[1,2] | spbb[2,1] > rsbb[2,2]) {
 		stop('polygon and raster have no overlapping areas')
@@ -654,7 +651,7 @@
 		} else {
 			rowcol[,1] <- r
 			sppoints <- xyFromCell(raster, cellFromRowCol(raster, rowcol[,1], rowcol[,2]), TRUE)
-			over <- over(sppoints, p)
+			over <- sp::over(sppoints, p)
 			vals <- putvals[over]
 		}
 		if (filename == "") {
